/* -*- Mode: C; c-file-style: "bsd" -*- */

#if !defined( _endian_h )
#define _endian_h

#if defined( __cplusplus )
extern "C" {
#endif

/* A run time endian test.  

   little_endian is the broken one: 80x86s, VAXs
   big_endian is: most unix machines, RISC chips, 68000, etc

   The endianess is stored in macros:

         little_endian
   and   big_endian

   These boolean values can be checked in your code in C expressions.

   They should NOT be tested with conditional macro statements (#ifdef
   etc).
*/

static int endian_test = 0x1ul;

#define little_endian ( *(char*)&endian_test == 1 )

#define big_endian ( ! little_endian )

void swap_endian16( void*, int );
void swap_endian32( void*, int );

#define make_big_endian32( data, len ) \
    ( little_endian ? swap_endian32( data, len ) : 0 )

#define make_big_endian16( data, len ) \
    ( little_endian ? swap_endian16( data, len ) : 0 )


#define make_little_endian32( data, len ) \
    ( little_endian ? 0 : swap_endian32( data, len ) )

#define make_little_endian16( data, len ) \
    ( little_endian ? 0 : swap_endian16( data, len ) )


#define make_local_endian32( data, len ) \
    ( little_endian ? swap_endian32( data, len ) : 0 )

#define make_local_endian16( data, len ) \
    ( little_endian ? swap_endian16( data, len ) : 0 )

#if defined( __cplusplus )
}
#endif

#endif
